Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(510)

Unified Diff: third_party/WebKit/WebCore/dom/WorkerContext.h

Issue 20076: WebKit merge 40500:40539 [WebKit side] (Closed) Base URL: svn://chrome-svn/chrome/trunk/src/
Patch Set: Created 11 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « third_party/WebKit/WebCore/dom/Worker.cpp ('k') | third_party/WebKit/WebCore/dom/WorkerContext.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: third_party/WebKit/WebCore/dom/WorkerContext.h
===================================================================
--- third_party/WebKit/WebCore/dom/WorkerContext.h (revision 9118)
+++ third_party/WebKit/WebCore/dom/WorkerContext.h (working copy)
@@ -41,6 +41,7 @@
namespace WebCore {
+ class ScheduledAction;
class WorkerLocation;
class WorkerNavigator;
class WorkerThread;
@@ -78,8 +79,11 @@
void postMessage(const String& message);
virtual void postTask(PassRefPtr<Task>); // Executes the task on context's thread asynchronously.
- void postTaskToParentContext(PassRefPtr<Task>); // Executes the task in the parent's context (and thread) asynchronously.
+ void postTaskToWorkerObject(PassRefPtr<Task>); // Executes the task on the worker object's thread asynchronously.
+ int installTimeout(ScheduledAction*, int timeout, bool singleShot);
+ void removeTimeout(int timeoutId);
+
virtual void addEventListener(const AtomicString& eventType, PassRefPtr<EventListener>, bool useCapture);
virtual void removeEventListener(const AtomicString& eventType, EventListener*, bool useCapture);
virtual bool dispatchEvent(PassRefPtr<Event>, ExceptionCode&);
« no previous file with comments | « third_party/WebKit/WebCore/dom/Worker.cpp ('k') | third_party/WebKit/WebCore/dom/WorkerContext.cpp » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698